//Bayesian Estimation of a new Keynesian model

var y r pi z_d z_p z_r y_obs pi_obs r_obs;

varexo e_d e_p e_r;

parameters sig chi gam xi iota  phi_pi phi_y phi_r piss rss rho_d rho_p rho_r;

model(linear);

#bet = 1/(1+rss/100);
#kap  = (1-xi)*(1-xi*bet)/xi;

//IS equation
(1+gam)*y = y(+1) + gam*y(-1) - (1-gam)/sig*(r-pi(+1)) + (1+gam)*z_d;

//New Keynesian Phillips curve
(1+bet*iota)*pi = bet*pi(+1) + iota*pi(-1) + kap*((chi+sig/(1-gam))*y - sig*gam/(1-gam)*y(-1)) + (1+bet*iota)*z_p;

//Monetary policy rule
r = phi_r*r(-1) + (1-phi_r)*(phi_pi*pi + phi_y*y) + z_r;

//shock processes
z_d = rho_d*z_d(-1) + e_d;
z_p = rho_p*z_p(-1) + e_p;
z_r = rho_r*z_r(-1) + e_r;

//measurement equations
y_obs  = y;
pi_obs = piss + pi;
r_obs = piss + rss + r;

end;

estimated_params;
sig, gamma_pdf, 1, 0.15;
chi, gamma_pdf, 2, 0.15;
gam, beta_pdf, 0.5, 0.15;
xi, beta_pdf, 0.75, 0.15;
iota, beta_pdf, 0.5, 0.15;

phi_pi, gamma_pdf, 1.5, 0.15;
phi_y, gamma_pdf, 0.5, 0.15;
phi_r, beta_pdf, 0.5, 0.15;

piss, gamma_pdf, 0.5, 0.15;
rss, gamma_pdf, 0.5, 0.15;

rho_d, beta_pdf, 0.5, 0.15;
rho_p, beta_pdf, 0.5, 0.15;
rho_r, beta_pdf, 0.5, 0.15;

stderr e_d, inv_gamma_pdf, 0.25, 2;   
stderr e_p, inv_gamma_pdf, 0.25, 2;   
stderr e_r, inv_gamma_pdf, 0.25, 2;   

end;

varobs y_obs pi_obs r_obs;

estimation(
datafile = simdata,
plot_priors=0,
nodiagnostic,
nograph,
bayesian_irf,IRF=15,
mh_replic = 200000,
mh_drop = 0.25,
mh_nblocks = 2,
mh_jscale = 0.575
)
y pi r
;
